@@ -5,8 +5,8 @@ resource_frequency_resource_activity <- function(log) {
 	relative_activity <- NULL
 
 	log %>%
-		group_by(!!resource_id_(log), !!activity_id_(log), !!activity_instance_id_(log)) %>%
-		#summarize() %>%
+		distinct(!!resource_id_(log), !!activity_id_(log), !!activity_instance_id_(log)) %>%
+		group_by(!!resource_id_(log), !!activity_id_(log)) %>%
 		summarize(absolute = n()) %>%
 		group_by(!!resource_id_(log)) %>%
 		mutate(relative_resource = absolute/sum(absolute)) %>%
